@@ -182,72 +182,72 @@ atspi_accessible_class_init (AtspiAccessibleClass *klass)
 static const char *role_names [] =
 {
   "invalid",
-  "accel-label",
+  "accelerator label",
   "alert",
   "animation",
   "arrow",
   "calendar",
   "canvas",
-  "check-box",
-  "check-menu-item",
-  "color-chooser",
-  "column-header",
-  "combo-box",
-  "date-editor",
-  "desktop-icon",
-  "desktop-frame",
+  "check box",
+  "check menu item",
+  "color chooser",
+  "column header",
+  "combo box",
+  "dateeditor",
+  "desktop icon",
+  "desktop frame",
   "dial",
   "dialog",
-  "directory-pane",
-  "drawing-area",
-  "file-chooser",
+  "directory pane",
+  "drawing area",
+  "file chooser",
   "filler",
   "focus traversable",
-  "font-chooser",
+  "fontchooser",
   "frame",
-  "glass-pane",
-  "html-container",
+  "glass pane",
+  "html container",
   "icon",
   "image",
-  "internalframe",
+  "internal frame",
   "label",
-  "layered-pane",
+  "layered pane",
   "list",
-  "list-item",
+  "list item",
   "menu",
-  "menu-bar",
-  "menu-item",
-  "option-pane",
-  "page-tab",
-  "page-tab-list",
+  "menu bar",
+  "menu item",
+  "option pane",
+  "page tab",
+  "page tab list",
   "panel",
-  "password-text",
-  "popup-menu",
-  "progress-bar",
-  "push-button",
-  "radio-button",
-  "radio-menu-item",
-  "root-pane",
-  "row-header",
-  "scroll-bar",
-  "scroll-pane",
+  "password text",
+  "popup menu",
+  "progress bar",
+  "push button",
+  "radio button",
+  "radio menu item",
+  "root pane",
+  "row header",
+  "scroll bar",
+  "scroll pane",
   "separator",
   "slider",
-  "spin-button",
-  "split-pane",
+  "spin button",
+  "split pane",
   "statusbar",
   "table",
-  "table-cell",
-  "table-column-header",
-  "table-row-header",
-  "tear-off-menu-item",
+  "table cell",
+  "table column header",
+  "table row header",
+  "tear off menu item",
   "terminal",
   "text",
-  "toggle-button",
-  "tool-bar",
-  "tool-tip",
+  "toggle button",
+  "tool bar",
+  "tool tip",
   "tree",
-  "tree-table",
+  "tree table",
   "unknown",
   "viewport",
   "window",
@@ -259,18 +259,31 @@ static const char *role_names [] =
   "application",
   "autocomplete",
   "editbar",
-  "embedded",
+  "embedded component",
   "entry",
   "chart",
   "caption",
-  "document_frame",
+  "document frame",
   "heading",
   "page",
   "section",
   "redundant object",
   "form",
   "link",
-  "input method window"
+  "input method window",
+  "table row",
+  "tree item",
+  "document spreadsheet",
+  "document presentation",
+  "document text",
+  "document web",
+  "document email",
+  "comment",
+  "list box",
+  "grouping",
+  "image map",
+  "notification",
+  "info bar"
 };
 
 #define MAX_ROLES (sizeof (role_names) / sizeof (char *))
